@@ -292,14 +292,14 @@ class DynamoRepository(Repository):
         return [item for single_response in query_responses for item in self._dynamo_items_parser(single_response)]
 
     @staticmethod
-    def _dynamo_attributes_parser(dynamo_response: DynamoAttributesResponse) -> [dict]:
-        """Return the parsed DynamoAttributesResponse as a list of dictionaries
+    def _dynamo_attributes_parser(dynamo_response: DynamoAttributesResponse) -> dict:
+        """Return the parsed DynamoAttributesResponse as a dictionary
 
         Args:
             dynamo_response (DynamoAttributesResponse): A DynamoAttributesResponse to parse
 
         Returns:
-            ([dict]) A list of dictionary representations of the DynamoAttributesResponse
+            (dict) A dictionary representation of the DynamoAttributesResponse
         """
         Logger().log(LogLevel.debug, dynamo_response._asdict(), title="Dynamo Attributes Response", pretty_json=True)
         return {key: convert_dynamo_data_to_python(dynamo_value) for key, dynamo_value in
