@@ -42,26 +42,46 @@ class ApiResponseException(Exception):
         self.message = message
 
 
-class ApiSuccessResponseBody(NamedTuple):
-    """NamedTuple for a successful response body"""
-    data: dict = {}
-    message: str = None
+class ApiSuccessResponseBody:
+    """Class for a successful response body
+
+    Attributes:
+        data (Any): The data returned in the response body
+        message (Optional[str]): the message returned with the response
+    """
+    data: Any
+    message: Optional[str]
+
+    def __init__(self, *, data: Optional[Any] = None, message: Optional[str] = None):
+        self.data = data or {}
+        self.message = message
 
     def append_data(self, data: Any, data_key: str):
-        """Append the given data with the data key
+        """Append the given data with the data key. Will overwrite existing data if not a dictionary.
 
         Args:
             data (Any): The data to append
             data_key (str): The key for the data
         """
+        if not self.data or type(self.data) is not dict:
+            self.data = {}
         self.data[data_key] = data
 
+    def set_data(self, data: Any):
+        """Set the body data to the given data
+
+        Args:
+            data (Any): The data to set
+        """
+        self.data = data
+
 
 class ApiErrorResponseBody(NamedTuple):
     """NamedTuple for an error response body"""
     error: str
 
 
+# noinspection PyUnresolvedReferences
 class Header(NamedTuple):
     """NamedTuple for an HTTP Header
 
@@ -121,6 +141,19 @@ class ApiResponseFactory(ABC):
         """
         return type(self.body) is ApiErrorResponseBody
 
+    @property
+    def body_dict(self) -> dict:
+        """Returns a dictionary of the response body
+
+        Returns:
+            (dict) The response body
+        """
+        if self.is_error:
+            # noinspection PyProtectedMember
+            return self.body._asdict()
+        else:
+            return vars(self.body)
+
     def set_error(self, error_code: Union[ResponseCode, int], message: str):
         """Set the error code and message for this response
 
@@ -171,7 +204,7 @@ class ApiResponseFactory(ABC):
         self.status_code = response_code.value
 
     def add_to_response_data(self, data: Any, data_key: str):
-        """Add the given data to the response with the given key
+        """Add the given data to the response with the given key if the response is a success response
 
         Args:
             data (Any): The data to add
@@ -180,22 +213,37 @@ class ApiResponseFactory(ABC):
         if type(self.body) is ApiSuccessResponseBody:
             self.body.append_data(data, data_key)
 
-    def set_response_from_actor(self, actor: Actor, use_case: UseCase, data_key: str, *, suppress_data=False,
-                                headers: Optional[List[Header]] = None):
+    def set_response_data(self, data: any):
+        """
+        Set the full response data object to the given data if the response is a success response
+
+        Args:
+            data (Any): The data to set
+        """
+        if type(self.body) is ApiSuccessResponseBody:
+            self.body.set_data(data)
+
+    def set_response_from_actor(self, actor: Actor, use_case: UseCase, data_key: Optional[str] = None, *,
+                                suppress_data=False, headers: Optional[List[Header]] = None):
         """Runs a use case on an actor, and set success for the use case along with response data
 
         Args:
             actor (Actor): The actor to operate
             use_case (UseCase): The use case to run
-            data_key (str): the data key to add response data to
+            data_key (Optional[str]): the data key to add response data to - will set the entire response data to the
+             given data if not provided
             suppress_data (bool): Prevent the returned data from being added to the response, but preserve success/error
              state information.
             headers (List[Header]): List of Header objects to add to the response
         """
         data = actor.run_use_case(use_case)
+
         self.set_success(use_case.name)
         if not suppress_data:
-            self.add_to_response_data(data, data_key)
+            if data_key:
+                self.add_to_response_data(data, data_key)
+            else:
+                self.set_response_data(data)
 
         if headers:
             for header in headers:
