@@ -43,20 +43,19 @@ class AwsApiGatewayResponseFactory(ApiResponseFactory):
         Returns:
             (dict) The instance's response
         """
-        # noinspection PyProtectedMember
         Logger().log(
             LogLevel.debug,
             {
                 'statusCode': self.status_code,
-                'body': self.body._asdict(),
+                'body': self.body_dict,
                 'headers': self.headers,
             },
             title="API Response",
             pretty_json=True
         )
-        # noinspection PyProtectedMember
+
         return {
             'statusCode': self.status_code,
-            'body': dumps(self.body._asdict()),
+            'body': dumps(self.body_dict),
             'headers': self.headers
         }
